@@ -5,6 +5,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 06.05.2014: Implemented 'checkDataset'.
@@ -29,6 +30,8 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils head help
+#' 
 #' @seealso \code{\link{addMarker}}
 
 addMarker_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
@@ -95,7 +98,7 @@ addMarker_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   f0g1[1,2] <- dataset_drp <- gdroplist(items=c("<Select dataset>",
                                                  listObjects(env=env,
-                                                             objClass="data.frame")),
+                                                             obj.class="data.frame")),
                                          selected = 1,
                                          editable = FALSE,
                                          container = f0g1)
