@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 26.09.2014: Implemented text field for 'exclude'.
 # 12.09.2014: Implemented new options 'exclude OL'.
@@ -34,6 +35,8 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help
+#' 
 #' @references
 #' Torben Tvedebrink, Poul Svante Eriksen, Helle Smidt Mogensen, Niels Morling,
 #'  Evaluating the weight of evidence by using quantitative short tandem repeat data in DNA mixtures
@@ -107,7 +110,7 @@ calculateHeight_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, p
   
   f0g0[1,2] <- dataset_drp <- gdroplist(items=c("<Select dataset>",
                                               listObjects(env=env,
-                                                          objClass="data.frame")), 
+                                                          obj.class="data.frame")), 
                                       selected = 1,
                                       editable = FALSE,
                                       container = f0g0)
