@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 27.08.2015: Updated text for option to calculate per marker.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
@@ -89,7 +90,7 @@ calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, pa
 
   g0[1,2] <- g0_dataset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
-                                               objClass="data.frame")), 
+                                               obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
                            container = g0)
@@ -138,7 +139,7 @@ calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, pa
                            checked = FALSE,
                            container = f1)
   
-  f1_per_marker_chk <- gcheckbox(text="Count peaks per marker.",
+  f1_per_marker_chk <- gcheckbox(text="Count peaks per marker (default is per sample).",
                             checked = FALSE,
                             container = f1)
   
