@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom.
 # 05.05.2015: Changed parameter 'ignoreCase' to 'ignore.case' for 'checkSubset' function.
 # 13.12.2014: Added kit dropdown and kit attribute to result.
 # 04.12.2014: First version.
@@ -26,7 +27,11 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help head str
+#' @importFrom graphics title
+#' 
 #' @seealso \code{\link{calculatePullup}}, \code{\link{checkSubset}}
+#' 
 
 
 calculatePullup_gui <- function(env=parent.frame(), savegui=NULL,
@@ -101,7 +106,7 @@ calculatePullup_gui <- function(env=parent.frame(), savegui=NULL,
   
   g0[1,1] <- glabel(text="Select dataset:", container=g0)
   
-  dfs <- c("<Select a dataset>", listObjects(env=env, objClass="data.frame"))
+  dfs <- c("<Select a dataset>", listObjects(env=env, obj.class="data.frame"))
   
   g0[1,2] <- g0_data_drp <- gdroplist(items=dfs, 
                                       selected = 1,
