@@ -4,6 +4,7 @@
 
 ###############################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom.
 # 04.06.2015: Changed button label 'Calculate result type' to 'Calculate'.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
@@ -27,6 +28,8 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help
+#' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{calculateResultType}}
@@ -95,7 +98,7 @@ calculateResultType_gui <- function(env=parent.frame(), savegui=NULL,
 
   g0[1,2] <- g0_dataset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
-                                               objClass="data.frame")), 
+                                               obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
                            container = g0)
