@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom.
 # 05.05.2015: Changed parameter 'ignoreCase' to 'ignore.case' for 'checkSubset' function.
 # 05.01.2015: Added kit dropdown and kit attribute to result.
 # 07.10.2014: Added 'focus', added 'parent' parameter.
@@ -23,8 +24,6 @@
 # 28.05.2013: Added warning for additive effects.
 # 24.05.2013: Improved error message for missing columns.
 # 17.05.2013: listDataFrames() -> listObjects()
-# 09.05.2013: .result removed, added save as group.
-# 27.04.2013: Added selection of dataframes from provided environment.
 
 #' @title Calculate Stutter
 #'
@@ -42,6 +41,9 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help head
+#' @importFrom graphics title
+#' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{calculateStutter}}, \code{\link{checkSubset}}
@@ -110,7 +112,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   f0g0[1,2] <- f0_dataset_drp <- gdroplist(items=c("<Select dataset>",
                                               listObjects(env=env,
-                                                          objClass="data.frame")), 
+                                                          obj.class="data.frame")), 
                                       selected = 1,
                                       editable = FALSE,
                                       container = f0g0)
@@ -154,7 +156,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   f0g0[2,2] <- f0_refset_drp <- gdroplist(items=c("<Select dataset>",
                                              listObjects(env=env,
-                                                         objClass="data.frame")), 
+                                                         obj.class="data.frame")), 
                                      selected = 1,
                                      editable = FALSE,
                                      container = f0g0) 
