@@ -6,6 +6,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 29.07.2014: Changed name concatenate_gui -> combine_gui.
 # 28.06.2014: Added help button and moved save gui checkbox.
@@ -30,6 +31,8 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help
+#' 
 #' @return TRUE
 
 
@@ -98,7 +101,7 @@ combine_gui <- function(env=parent.frame(), debug=FALSE, parent=NULL){
   
   f0g0[1,2] <- f0g0_data1_drp <- gdroplist(items=c("<Select dataset>",
                                                  listObjects(env=env,
-                                                             objClass="data.frame")),
+                                                             obj.class="data.frame")),
                                          selected = 1,
                                          editable = FALSE,
                                          container = f0g0)
@@ -138,7 +141,7 @@ combine_gui <- function(env=parent.frame(), debug=FALSE, parent=NULL){
   
   f0g0[2,2] <- f0g0_data2_drp <- gdroplist(items=c("<Select dataset>",
                                                  listObjects(env=env,
-                                                             objClass="data.frame")),
+                                                             obj.class="data.frame")),
                                          selected = 1,
                                          editable = FALSE,
                                          container = f0g0)
