@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.08.2015: Added importFrom.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 07.05.2014: Implemented 'checkDataset'.
@@ -37,6 +38,8 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help head str tail
+#' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{trim_gui}}, \code{\link{editData_gui}}, \code{\link{combine_gui}}
@@ -104,7 +107,7 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=N
   
   g0[1,2] <- dataset_drp <- gdroplist(items=c("<Select data frame>",
                                               listObjects(env=env,
-                                                          objClass="data.frame")), 
+                                                          obj.class="data.frame")), 
                                       selected = 1,
                                       editable = FALSE,
                                       container = g0)
