@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 29.08.2015: Added importFrom.
 # 05.05.2015: Changed parameter 'ignoreCase' to 'ignore.case' for 'checkSubset' function.
 # 09.04.2015: Added option 'invert' to filter peaks NOT in reference.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
@@ -40,6 +41,9 @@
 #' 
 #' @export
 #' 
+#' @importFrom utils help str
+#' @importFrom graphics title
+#' 
 #' @return TRUE
 #' 
 #' @seealso \code{\link{filterProfile}}, \code{\link{checkSubset}}
@@ -107,7 +111,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, par
 
   g0[1,2] <- g0_dataset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
-                                               objClass="data.frame")), 
+                                               obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
                            container = g0)
@@ -154,7 +158,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, par
   
   g0[2,2] <- g0_refset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
-                                               objClass="data.frame")), 
+                                               obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
                            container = g0) 
