@@ -31,3 +31,9 @@ if (base::getRversion() >= "2.15.1") {
                            "ggplotGrob","ggplot_build")) 
 }
 
+## Needed to avoid notes when using data.table in functions:
+## calculateAT, calculateAT_gui, calculateAT6, calculateAT6_gui, plotBalance_gui
+if (base::getRversion() >= "2.15.1") {
+  utils::globalVariables(c("Height","Blocked","Sample.File.Name","Dye",
+                           "Hb","Marker","Lb", "H", "Amount"))
+}
\ No newline at end of file
