@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 29.08.2015: Added importFrom.
 # 05.01.2015: 'Save as object' now disabled when complex plot.
 # 14.12.2014: Option to drop sex markers.
 # 14.12.2014: Updated to handle gender -> sex.marker option in getKit.
@@ -40,14 +41,17 @@
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
 #' 
-# @importFrom gridExtra arrangeGrob
-# @importFrom gtable gtable_add_grob gtable gtable_filter
-# @importFrom plyr rbind.fill
-# @importFrom scales pretty_breaks
+#' @return TRUE
 #' 
 #' @export
 #' 
-#' @return TRUE
+# @importFrom gridExtra arrangeGrob
+# @importFrom gtable gtable_add_grob gtable gtable_filter
+#' @importFrom plyr rbind.fill
+#' @importFrom scales pretty_breaks
+#' @importFrom utils help str
+#' @importFrom stats as.formula
+#' @importFrom grDevices hcl
 #' 
 #' @seealso \url{http://docs.ggplot2.org/current/} for details on plot settings.
 
@@ -112,7 +116,7 @@ plotStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, paren
 
   dataset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
-                                               objClass="data.frame")), 
+                                               obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
                            container = f0) 
