@@ -5,6 +5,7 @@
 # NB! Can't handle Sample.Names as factors?
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 29.08.2015: Added importFrom.
 # 23.05.2015: Re-named internal variable 'new' (R function) to 'new_val'.
 # 11.05.2015: Accepts (the first) column name containing the string 'Sample'
 # as alternative to colum name 'Sample.Name'. All made case in-sensitive.
@@ -41,11 +42,14 @@
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
 #' 
-#' @export
-#' 
 #' @return TRUE
 #' 
+#' @export
+#' 
+#' @importFrom utils help
+#' 
 #' @seealso \code{\link{trim}}
+#' 
 
 
 trim_gui <- function(env=parent.frame(), savegui=NULL,
@@ -136,7 +140,7 @@ trim_gui <- function(env=parent.frame(), savegui=NULL,
   
   g0[1,2] <- dataset_drp <- gdroplist(items=c("<Select dataset>",
                                                  listObjects(env=env,
-                                                             objClass="data.frame")),
+                                                             obj.class="data.frame")),
                                          selected = 1,
                                          editable = FALSE,
                                          container = g0)
